import { execSync } from "child_process";
import { copyFolderSync, replaceNamespace } from "../utils/utils.js";
import { fileURLToPath } from "url";
import path from "path";

export const setupGulp = async (dir: string, name: string): Promise<void> => {
  console.log(`Setup Gulp\n`);

  const __filename = fileURLToPath(import.meta.url);
  const __dirname = path.dirname(__filename);

  // Get the template of the gulp folder
  const gulpDir = path.join(__dirname, "..", "template/gulp");
  copyFolderSync(gulpDir, dir);

  // Update README.md to Node Version
  const filePath = path.join(dir, "README.md");
  replaceNamespace(filePath, `{{NODE_VERSION}}`, process.version.replace("v", "") || "");

  //go to all files and replace `{%NAMESPACE%}` with the project name in uppercase
  replaceNamespace(dir, `{%NAMESPACE%}`, name);

  // Install Gulp and dependencies
  try {
    execSync(`cd ${dir} && npm init -y`, { stdio: "inherit" });
    execSync(`cd ${dir} && npm install gulp --save-dev`, { stdio: "inherit" });
    execSync(`cd ${dir} && npm install --global gulp-cli`, { stdio: "inherit" });
    execSync(`cd ${dir} && npm install gulp-sass --save-dev`, { stdio: "inherit" });
    execSync(`cd ${dir} && npm install sass --save-dev`, { stdio: "inherit" });
    execSync(`cd ${dir} && npm install gulp-concat --save-dev`, { stdio: "inherit" });
    execSync(`cd ${dir} && npm install gulp-uglify --save-dev`, { stdio: "inherit" });
    execSync(`cd ${dir} && npm install gulp-clean-css --save-dev`, { stdio: "inherit" });
    execSync(`cd ${dir} && npm install gulp-sourcemaps --save-dev`, { stdio: "inherit" });
    execSync(`cd ${dir} && npm install gulp-autoprefixer --save-dev`, { stdio: "inherit" });
    execSync(`cd ${dir} && npm install gulp-sass-glob --save-dev`, { stdio: "inherit" });
    execSync(`cd ${dir} && npm install --save-dev gulp-babel @babel/core @babel/preset-env`, {
      stdio: "inherit",
    });
  } catch (error) {
    console.error(error);
  }
};
