import { execSync } from "child_process";
import inquirer from "inquirer";

// Main function to ask questions and generate the command
export const setupVue = async (dir: string, name: string): Promise<void> => {
  console.log(`SETUP VUE\n`);

  // Questions for the user
  const answers = await inquirer.prompt([
    {
      type: "list",
      name: "type",
      message: "Do you want to use Nuxt.js or standard Vue?",
      choices: ["Nuxt.js", "Standard Vue"],
      default: "Standard Vue",
    },
  ]);

  // Build the base command for Vue setup
  let command =
    answers.type === "Nuxt.js"
      ? `npx nuxi@latest init ${name.toLowerCase()}`
      : `npm create vue@latest ${name.toLowerCase()}`;

  // Execute the generated command
  console.log(`Executing: ${command}`);
  try {
    execSync(`cd ${dir} && ${command}`, { stdio: "inherit" });
    console.log("Vue project setup completed successfully!");
  } catch (error) {
    console.error("Error executing command:", error);
  }
};
