const gulp = require('gulp');
const sass = require('gulp-sass')(require('sass'));
const concat = require('gulp-concat');
const uglify = require('gulp-uglify');
const cleanCSS = require('gulp-clean-css');
const sourcemaps = require('gulp-sourcemaps');
const sassGlob = require('gulp-sass-glob');
const babel = require('gulp-babel');

const paths = {
	scss: ['scss/**/*.scss', './components/**/*.scss', './modules/**/*.scss'],
	js: ['main.js', 'utils/**/*.js', './components/**/*.js', './modules/**/*.js'],
};

const isProduction = process.env.NODE_ENV === 'production';

// Task to compile SCSS files to CSS
gulp.task('styles', function () {
	let pipeline = gulp.src(paths.scss);

	if (!isProduction) {
		pipeline = pipeline.pipe(sourcemaps.init());
	}

	pipeline = pipeline
		.pipe(sassGlob()) // Allows the use of glob imports in SCSS
		.pipe(sass().on('error', sass.logError)) // Compiles SCSS to CSS
		.pipe(cleanCSS()) // Minifies the CSS
		.pipe(concat('main.css')); // Concatenates all CSS files into one

	if (!isProduction) {
		pipeline = pipeline.pipe(sourcemaps.write('.'));
	}

	// If you want a different destination for the project, just add gulp.dest with the new path
	// return pipeline.pipe(gulp.dest("../...webroot/js"));
	return pipeline.pipe(gulp.dest('dist/css')); // Outputs the final CSS file to the dist/css directory
});

// Task to compile and minify JavaScript files
gulp.task('scripts', function () {
	let pipeline = gulp.src(paths.js);

	pipeline = pipeline.pipe(
		babel({
			presets: ['@babel/env'], // Transpiles ES6+ code to ES5
		}),
	);

	if (!isProduction) {
		pipeline = pipeline.pipe(sourcemaps.init());
	}

	pipeline = pipeline
		.pipe(concat('bundle.js')) // Concatenates all JS files into one
		.pipe(uglify()); // Minifies the JS

	if (!isProduction) {
		pipeline = pipeline.pipe(sourcemaps.write('.'));
	}

	// If you want a different destination for the project, just add gulp.dest with the new path
	// return pipeline.pipe(gulp.dest("../...webroot/js"));
	return pipeline.pipe(gulp.dest('dist/js')); // Outputs the final JS file to the dist/js directory
});

// Task to watch for changes in SCSS and JS files
gulp.task('watch', function () {
	gulp.watch(paths.scss, gulp.series('styles')); // Watches SCSS files and runs the styles task on change
	gulp.watch(paths.js, gulp.series('scripts')); // Watches JS files and runs the scripts task on change
});

// Default task that runs styles, scripts, and watch tasks
gulp.task('default', gulp.series('styles', 'scripts', 'watch'));

// Task for production build
gulp.task('production', gulp.series('styles', 'scripts'));

// Task for development build
gulp.task('dev', gulp.series('styles', 'scripts'));
